@@ -185,3 +185,7 @@ def rstrip_space_in_file(file_path, line_number):
                 print(line.rstrip() + "\n", end='')
             else:
                 print(line, end='')
+
+def display_image(img_file):
+    from IPython.display import Image
+    Image(img_file)
